package Bundle::Locale::CLDR::Southerneurope;

use version;

our $VERSION = version->declare('v0.44.1');

=head1 NAME

Bundle::Locale::CLDR::Southerneurope

=head1 CONTENTS

Locale::CLDR::Locales::An 0.44.1

Locale::CLDR::Locales::Bs 0.44.1

Locale::CLDR::Locales::Ca 0.44.1

Locale::CLDR::Locales::De 0.44.1

Locale::CLDR::Locales::El 0.44.1

Locale::CLDR::Locales::Es 0.44.1

Locale::CLDR::Locales::Eu 0.44.1

Locale::CLDR::Locales::Gl 0.44.1

Locale::CLDR::Locales::Hr 0.44.1

Locale::CLDR::Locales::It 0.44.1

Locale::CLDR::Locales::La 0.44.1

Locale::CLDR::Locales::Mk 0.44.1

Locale::CLDR::Locales::Mt 0.44.1

Locale::CLDR::Locales::Oc 0.44.1

Locale::CLDR::Locales::Pt 0.44.1

Locale::CLDR::Locales::Sc 0.44.1

Locale::CLDR::Locales::Sl 0.44.1

Locale::CLDR::Locales::Sq 0.44.1

Locale::CLDR::Locales::Sr 0.44.1

Locale::CLDR::Locales::Ast 0.44.1

Locale::CLDR::Locales::Fur 0.44.1

Locale::CLDR::Locales::Lij 0.44.1

Locale::CLDR::Locales::Lmo 0.44.1

Locale::CLDR::Locales::Scn 0.44.1

Locale::CLDR::Locales::Vec 0.44.1

Locale::CLDR::Locales::An::Latn 0.44.1

Locale::CLDR::Locales::Bs::Cyrl 0.44.1

Locale::CLDR::Locales::Bs::Latn 0.44.1

Locale::CLDR::Locales::Ca::Latn 0.44.1

Locale::CLDR::Locales::De::Latn 0.44.1

Locale::CLDR::Locales::El::Grek 0.44.1

Locale::CLDR::Locales::Es::Latn 0.44.1

Locale::CLDR::Locales::Eu::Latn 0.44.1

Locale::CLDR::Locales::Gl::Latn 0.44.1

Locale::CLDR::Locales::Hr::Latn 0.44.1

Locale::CLDR::Locales::It::Latn 0.44.1

Locale::CLDR::Locales::La::Latn 0.44.1

Locale::CLDR::Locales::Mk::Cyrl 0.44.1

Locale::CLDR::Locales::Mt::Latn 0.44.1

Locale::CLDR::Locales::Oc::Latn 0.44.1

Locale::CLDR::Locales::Pt::Latn 0.44.1

Locale::CLDR::Locales::Sc::Latn 0.44.1

Locale::CLDR::Locales::Sl::Latn 0.44.1

Locale::CLDR::Locales::Sq::Latn 0.44.1

Locale::CLDR::Locales::Sr::Cyrl 0.44.1

Locale::CLDR::Locales::Sr::Latn 0.44.1

Locale::CLDR::Locales::Ast::Latn 0.44.1

Locale::CLDR::Locales::Fur::Latn 0.44.1

Locale::CLDR::Locales::Lij::Latn 0.44.1

Locale::CLDR::Locales::Lmo::Latn 0.44.1

Locale::CLDR::Locales::Scn::Latn 0.44.1

Locale::CLDR::Locales::Vec::Latn 0.44.1

Locale::CLDR::Locales::An::Latn::Es 0.44.1

Locale::CLDR::Locales::Bs::Cyrl::Ba 0.44.1

Locale::CLDR::Locales::Bs::Latn::Ba 0.44.1

Locale::CLDR::Locales::Ca::Latn::Ad 0.44.1

Locale::CLDR::Locales::Ca::Latn::Es 0.44.1

Locale::CLDR::Locales::Ca::Latn::It 0.44.1

Locale::CLDR::Locales::De::Latn::It 0.44.1

Locale::CLDR::Locales::El::Grek::Gr 0.44.1

Locale::CLDR::Locales::En::Latn::Gi 0.44.1

Locale::CLDR::Locales::En::Latn::Mt 0.44.1

Locale::CLDR::Locales::En::Latn::Si 0.44.1

Locale::CLDR::Locales::Es::Latn::Es 0.44.1

Locale::CLDR::Locales::Eu::Latn::Es 0.44.1

Locale::CLDR::Locales::Gl::Latn::Es 0.44.1

Locale::CLDR::Locales::Hr::Latn::Ba 0.44.1

Locale::CLDR::Locales::Hr::Latn::Hr 0.44.1

Locale::CLDR::Locales::It::Latn::It 0.44.1

Locale::CLDR::Locales::It::Latn::Sm 0.44.1

Locale::CLDR::Locales::It::Latn::Va 0.44.1

Locale::CLDR::Locales::La::Latn::Va 0.44.1

Locale::CLDR::Locales::Mk::Cyrl::Mk 0.44.1

Locale::CLDR::Locales::Mt::Latn::Mt 0.44.1

Locale::CLDR::Locales::Oc::Latn::Es 0.44.1

Locale::CLDR::Locales::Pt::Latn::Pt 0.44.1

Locale::CLDR::Locales::Sc::Latn::It 0.44.1

Locale::CLDR::Locales::Sl::Latn::Si 0.44.1

Locale::CLDR::Locales::Sq::Latn::Al 0.44.1

Locale::CLDR::Locales::Sq::Latn::Mk 0.44.1

Locale::CLDR::Locales::Sq::Latn::Xk 0.44.1

Locale::CLDR::Locales::Sr::Cyrl::Ba 0.44.1

Locale::CLDR::Locales::Sr::Cyrl::Me 0.44.1

Locale::CLDR::Locales::Sr::Cyrl::Rs 0.44.1

Locale::CLDR::Locales::Sr::Cyrl::Xk 0.44.1

Locale::CLDR::Locales::Sr::Latn::Ba 0.44.1

Locale::CLDR::Locales::Sr::Latn::Me 0.44.1

Locale::CLDR::Locales::Sr::Latn::Rs 0.44.1

Locale::CLDR::Locales::Sr::Latn::Xk 0.44.1

Locale::CLDR::Locales::Ast::Latn::Es 0.44.1

Locale::CLDR::Locales::En::Latn::001 0.44.1

Locale::CLDR::Locales::En::Latn::150 0.44.1

Locale::CLDR::Locales::Fur::Latn::It 0.44.1

Locale::CLDR::Locales::Lij::Latn::It 0.44.1

Locale::CLDR::Locales::Lmo::Latn::It 0.44.1

Locale::CLDR::Locales::Scn::Latn::It 0.44.1

Locale::CLDR::Locales::Vec::Latn::It 0.44.1


=cut

1;

